@@ -1,4 +1,4 @@
-# $Id: Text.pm,v 1.69 2014/01/15 21:32:45 pfeiffer Exp $
+# $Id: Text.pm,v 1.72 2017/07/26 22:11:11 pfeiffer Exp $
 
 =head1 NAME
 
@@ -13,8 +13,7 @@ require Exporter;
 
 @EXPORT = qw(find_unquoted rfind_unquoted split_on_whitespace join_with_protection
 	     split_on_colon split_commands unquote unquote_split_on_whitespace
-	     requote format_exec_args whitespace_len hash_neq is_cpp_source_name
-	     is_object_or_library_name);
+	     format_exec_args hash_neq is_cpp_source_name is_object_or_library_name);
 
 use Config;
 
@@ -22,7 +21,7 @@ BEGIN {
   # Keep it here, as this is the common to all mpp* utilities.
   our $BASEVERSION = 2.1;
 #@@setVERSION
-  our $VERSION = '2.0.98.4.9cvs';
+  our $VERSION = '2.0.98.5.1cvs';
 
 #
 # Not installed, so grep all our sources for the checkin date.  Make a
@@ -35,7 +34,7 @@ BEGIN {
   if( $VERSION =~ tr/a-z//d ) {
     my %VERSION = qw(0/00/00 0 00/00/00 0); # Default in case all modules change on same day.
     for( <$Mpp::datadir/makep*[!~] $Mpp::datadir/Mpp{,/*,/*/*}.pm> ) {
-      open my( $fh ), $_;
+      open my $fh, '<', $_;
       while( <$fh> ) {
 	if( /\$Id: .+,v [.0-9]+ ([\/0-9]+)/ ) {
 	  $VERSION{$1}++;
@@ -465,23 +464,6 @@ sub unquote {
   $ret_str;
 }
 
-=head2 requote
-
-  $quoted_text = requote($unquoted_text);
-
-Puts quotes around the text, and escapes any quotes inside the text, so
-that calling unquote() on $quoted_text will return the same string as
-$unquoted_text.
-
-=cut
-
-sub requote {
-  my( $str ) = @_;		# Get a modifiable copy of the string.
-  $str =~ s/["\\]/\\$&/g;	# Protect all backslashes and double quotes.
-  $str =~ s{[\0-\037]}{sprintf '\%o', ord $&}eg; # Protect any binary characters.
-  qq["$str"];			# Return the quoted string.
-}
-
 #
 # Perl contains an optimization where it won't run a shell if it thinks the
 # command has no shell metacharacters.	However, its idea of shell
@@ -628,7 +610,7 @@ my $args;
 my $argfile =
   ['A', qr/arg(?:ument)?s?[-_]?file/, \$args, 1,
    sub {
-     open my $fh, $args or die "$0: cannot open args-file `$args'--$!\n";
+     open my $fh, '<', $args or die "$0: cannot open args-file `$args'--$!\n";
      local $/;
      unshift @ARGV, unquote_split_on_whitespace <$fh>;
      close $fh;
@@ -735,7 +717,7 @@ For details look";
   $helpend =~ s/\@BASEVERSION\@/$BASEVERSION/;
   our $opts ||= $pod;
   print "\n";
-  open my $fh, "$Mpp::datadir/pod/$opts.pod" or die $!;
+  open my $fh, '<', "$Mpp::datadir/pod/$opts.pod" or die $!;
   my $opt = $/ = '';
   my $found;
   while( <$fh> ) {		# skip to before 1st opt
